@@ -33,9 +33,18 @@ class WithContext(object):
 class DoxyCPPClassObject(cpp.CPPClassObject):
     __bases = []
 
+    @property
+    def display_object_type(self):
+        # override because we also have the 'interface' type
+        assert self.objtype in ('class', 'struct', 'interface')
+        # TODO: remove this if it should be rendered as 'interface' as well
+        if self.objtype == 'interface':
+            return 'class'
+        return self.objtype
+
     def parse_definition(self, parser):
         # add the base classes
-        ast = parser.parse_declaration("class")
+        ast = parser.parse_declaration("class", "class")
 
         bases = []
 
@@ -184,7 +193,8 @@ def get_param_decl(param):
     if not param_name:
         param_decl = param_type
     else:
-        param_decl, number_of_subs = re.subn(r'(\([*&]+)(\))', r'\g<1>' + param_name + r'\g<2>',
+        param_decl, number_of_subs = re.subn(r'(\((?:\w+::)*[*&]+)(\))',
+                                             r'\g<1>' + param_name + r'\g<2>',
                                              param_type)
         if number_of_subs == 0:
             param_decl = param_type + ' ' + param_name
@@ -204,6 +214,8 @@ def get_definition_without_template_args(data_object):
     For example in 'Result<T> A< B<C> >::f' we want to remove the '< B<C> >' part.
     """
     definition = data_object.definition
+    if (len(data_object.bitfield) > 0):
+        definition += " : " + data_object.bitfield
     qual_name = '::' + data_object.name
     if definition.endswith(qual_name):
         qual_name_start = len(definition) - len(qual_name)
@@ -795,7 +807,7 @@ class SphinxRenderer(object):
                 rst_node = self.node_factory.math()
             else:
                 # Else we're multiline
-                rst_node = self.node_factory.displaymath()
+                rst_node = self.node_factory.math_block()
 
             # Or multiline
             if latex.startswith("\\[") and latex.endswith("\\]"):
@@ -1075,6 +1087,7 @@ class SphinxRenderer(object):
             else:
                 signature[0] = annotation
 
+        declaration = self.create_template_prefix(node) + declaration
         return self.render_declaration(node, declaration, objtype=obj_type,
                                        update_signature=update_signature)
 
@@ -1098,6 +1111,7 @@ class SphinxRenderer(object):
         if declaration.startswith(enum):
             declaration = declaration[len(enum):]
         declaration += self.make_initializer(node)
+        declaration = self.create_template_prefix(node) + declaration
         return self.render_declaration(node, declaration)
 
     def visit_enumvalue(self, node):
